@@ -11,7 +11,7 @@ our @ISA = qw(Exporter);
 our @EXPORT_OK = qw(is_less_or_equal);
 our @EXPORT = qw();
 
-our $VERSION = '0.25';
+our $VERSION = '0.26';
 
 require XSLoader;
 XSLoader::load('Regexp::Compare', $VERSION);
@@ -82,7 +82,7 @@ constructs
 
 =head1 AUTHOR
 
-Vaclav Barta, E<lt>vbar@comp.czE<gt>
+Vaclav Barta, E<lt>vbarta@mangrove.czE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
